================
Morp Templates
================

This package contains cookiecutter based code generator for Morp Framework.

.. automodule:: mfw_template.commands

.. click:: mfw_template.cli:app
   :prog: mfw-template
   :show-nested:
